import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

import "dateExt.js" as DateExt
import "GlobalEventModel.js" as GlobalModel

Item {
    id: root
    objectName: "AgendaView"

    property var model;


    Label {
        id: noEvent
        objectName: "noEvent"

        width: parent.width-units.gu(6)
        visible: eventModel.count === 0
        anchors.centerIn: parent

        fontSize: "medium"
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignHCenter

        text:  i18n.tr("No incoming event")
    }

    Column {
        id: column
        anchors.top: parent.top
        anchors.topMargin: units.gu(1.5)
        width: parent.width; height: parent.height
        spacing: units.gu(1)

        anchors.fill: parent

        Component.onCompleted: {
            model = GlobalModel.globalModel();
            model.reloaded.connect(buildList);
        }

        function buildList () {
            eventModel.clear();
            // Include all events from 00:00 so you can still consult the past events of the day
            // (or just you are late 10 minutes to your RDV, and you need details from the event...)
            var itemIds = model.itemIds(new Date().midnight());
            for(var i = 0 ; i < itemIds.length ; ++i) {
                var eventId = itemIds[(i)];
                var event = model.item(eventId);
                if( event ) {
                    // Recreating new ListItem model, because
                    // 1. I'm not able to take control on section.property formating in ListView
                    // 2. section in deledate has been cast to string (even if property was a QDateTime
                    // 3. no way to cheat like adding on the fly a method or property to the ListItem while looping
                    eventModel.append({
                        sectionLabel: event.startDateTime.formatDate(),
                        event: event
                    });
                }
            }
        }

        ListModel {
            id: eventModel
        }

        Component {
            id: dateHeading
            ListItem.Header {
                text: section
            }
        }

        ListView {
            id: eventList
            model: eventModel

            width: parent.width
            height: parent.height
            anchors { left: parent.left; right: parent.right}
            clip: true

            section.property: "sectionLabel"
            section.criteria: ViewSection.FullString
            section.labelPositioning: ViewSection.InlineLabels
            section.delegate: dateHeading

            delegate: ListItem.Standard {
                id: eventItem
                text: event.startDateTime.formatTime() + " - " + event.displayLabel
                progression: true
                onClicked: {
                    pageStack.push(Qt.resolvedUrl("EventDetails.qml"),{"event": model.event});
                }

            }
            Scrollbar {
                flickableItem: eventList
            }
        }

    }
}
